==> apache-camel-3.3.0-src.zip: apache-camel-3.3.0/core/camel-core/src/test/java/org/apache/camel/issues/OnExceptionErrorHandlerNoRouteOnExchangeIssueTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.issues;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.LoggingLevel;
import org.apache.camel.builder.RouteBuilder;
import org.junit.Test;

public class OnExceptionErrorHandlerNoRouteOnExchangeIssueTest  extends ContextTestSupport {

    @Test
    public void testOk() throws Exception {
        String out = template.requestBody("direct:hello", null, String.class);
        assertEquals("Hello World", out);
    }

    @Test
    public void testNormalError() throws Exception {
        String out = template.requestBody("direct:normalError", null, String.class);
        assertEquals("general exception was properly handled", out);
    }

    @Test
    public void testBug() throws Exception {
        String out = template.requestBody("direct:bug", null, String.class);
        assertEquals("general exception was properly handled", out);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                onException(Exception.class)
                        .handled(true)
                        .log(LoggingLevel.ERROR, "error", "${messageHistory} \n ${exchange} \n ${exception.stacktrace}")
                        .transform().simple("general exception was properly handled")
                        .stop();

                from("direct:hello").routeId("routeHello")
                        .transform().constant("Hello World")
                        .setHeader(Exchange.HTTP_RESPONSE_CODE, constant(200));

                from("direct:normalError").routeId("normalError")
                        .throwException(new NullPointerException("some null value"))
                        .to("direct:hello");

                from("direct:bug").routeId("routeBug")
                        .to("direct:detour")
                        .throwException(new NullPointerException("something went wrong"))
                        .to("direct:hello");

                from("direct:detour").routeId("routeDetour1")
                        .to("direct:detour2");

                from("direct:detour2").routeId("routeDetour2")
                        .transform().constant("random processing (should not be exposed)");
            }
        };
    }
}

==> apache-camel-3.4.6-src.zip: apache-camel-3.4.6/core/camel-core/src/test/java/org/apache/camel/issues/OnExceptionErrorHandlerNoRouteOnExchangeIssueTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.issues;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.LoggingLevel;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class OnExceptionErrorHandlerNoRouteOnExchangeIssueTest  extends ContextTestSupport {

    @Test
    public void testOk() throws Exception {
        String out = template.requestBody("direct:hello", null, String.class);
        assertEquals("Hello World", out);
    }

    @Test
    public void testNormalError() throws Exception {
        String out = template.requestBody("direct:normalError", null, String.class);
        assertEquals("general exception was properly handled", out);
    }

    @Test
    public void testBug() throws Exception {
        String out = template.requestBody("direct:bug", null, String.class);
        assertEquals("general exception was properly handled", out);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                onException(Exception.class)
                        .handled(true)
                        .log(LoggingLevel.ERROR, "error", "${messageHistory} \n ${exchange} \n ${exception.stacktrace}")
                        .transform().simple("general exception was properly handled")
                        .stop();

                from("direct:hello").routeId("routeHello")
                        .transform().constant("Hello World")
                        .setHeader(Exchange.HTTP_RESPONSE_CODE, constant(200));

                from("direct:normalError").routeId("normalError")
                        .throwException(new NullPointerException("some null value"))
                        .to("direct:hello");

                from("direct:bug").routeId("routeBug")
                        .to("direct:detour")
                        .throwException(new NullPointerException("something went wrong"))
                        .to("direct:hello");

                from("direct:detour").routeId("routeDetour1")
                        .to("direct:detour2");

                from("direct:detour2").routeId("routeDetour2")
                        .transform().constant("random processing (should not be exposed)");
            }
        };
    }
}
